@@ -1,4 +1,4 @@
-# $Id: Config.pm,v 1.48 2005/05/16 11:22:25 joern Exp $
+# $Id: Config.pm,v 1.49 2005/06/19 13:38:24 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -308,6 +308,12 @@ my %CONFIG_PARAMETER = (
 		type	=> 'switch',
 		value	=> 1,
 	},
+	nptl_ld_assume_kernel => {
+		label   => __"Set LD_ASSUME_KERNEL to",
+		type    => "string",
+		value   => "2.4.30",
+		chained => 1,
+	},
 );
 
 my @CONFIG_ORDER = (
@@ -340,7 +346,7 @@ my @CONFIG_ORDER = (
 		default_bpp
 		main_window_width    main_window_height
 		preferred_lang       show_tooltips
-		workaround_nptl_bugs
+		workaround_nptl_bugs nptl_ld_assume_kernel
 	)],
 );
 
@@ -617,7 +623,7 @@ sub init_nptl_bug_workaround {
 	my $self = shift;
 	
 	if ( $self->get_value("workaround_nptl_bugs") ) {
-		$ENV{LD_ASSUME_KERNEL} = "2.2.5";
+		$ENV{LD_ASSUME_KERNEL} = $self->get_value('nptl_ld_assume_kernel');
 	} else {
 		delete $ENV{LD_ASSUME_KERNEL};
 	}
@@ -686,7 +692,7 @@ sub save {
 	my $fh = FileHandle->new;
 
 	open ($fh, "> $filename") or die "can't write $filename";
-	print $fh q{# $Id: Config.pm,v 1.48 2005/05/16 11:22:25 joern Exp $},"\n";
+	print $fh q{# $Id: Config.pm,v 1.49 2005/06/19 13:38:24 joern Exp $},"\n";
 	print $fh "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
 
 	print $fh ${$data_sref};
