@@ -1,4 +1,4 @@
-# $Id: Message.pm,v 1.4 2003/01/28 20:19:57 joern Exp $
+# $Id: Message.pm,v 1.6 2005/06/19 13:41:53 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -9,6 +9,7 @@
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::RPC::Message;
+use Locale::TextDomain qw (video.dvdrip);
 
 use base Video::DVDRip::Base;
 
@@ -20,7 +21,7 @@ sub pack {
 	my $class = shift;
 	my ($ref) = @_;
 
-	my $packed = Storable::freeze ($ref);
+	my $packed = Storable::nfreeze ($ref);
 
 	$packed =~ s/\\/\\\\/g;
 	$packed =~ s/\n/\\n/g;
